@@ -112,3 +112,12 @@ class Error(BaseModel):
 
 # Type alias for all components
 Component = Union[Text, Image, Markdown, Card, Cards, Done, Pill, Pills, Video, Block, Error]
+
+
+class BaseComponent(BaseModel):
+    """A unified wrapper for any component, with metadata like thread_id"""
+    thread_id: Optional[str] = None
+    payload: Component
+    
+    def __init__(self, payload: Component, thread_id: Optional[str] = None):
+        super().__init__(payload=payload, thread_id=thread_id)
