@@ -17,24 +17,53 @@ from typing import (
 )
 from functools import wraps
 
-from .components import Component, Done
+from .components import Component, Done, BaseComponent
 from .schemas import ComponentChatRequest, ComponentChatResponse, ImageInput, BotConfig
 
-# Module-level registry for config function
+# Module-level registry for config function (deprecated, for backward compatibility)
 _config_function: Optional[Tuple[Callable, str]] = None
 
+# Module-level registry for all chatbot functions
+_chatbot_registry: Dict[str, 'ChatbotFunction'] = {}
+
+# Module-level registry for bot-specific config functions
+_bot_config_registry: Dict[str, Callable] = {}
+
 
 class ChatbotFunction:
     """Wrapper for chatbot functions"""
 
-    def __init__(self, func: Callable, name: str = None, stream: bool = None):
+    def __init__(self, func: Callable, name: str = None, stream: bool = None, url_path: str = None):
         self.func = func
         self.name = name or func.__name__
+        self.url_path = url_path or "/chat"  # Default to /chat if not specified
         self.is_async = inspect.iscoroutinefunction(func)
         self.is_generator = inspect.isgeneratorfunction(
             func
         ) or inspect.isasyncgenfunction(func)
         self.stream = stream if stream is not None else self.is_generator
+        self._config_func = None  # Store bot-specific config
+    
+    def config(self, func: Callable) -> Callable:
+        """
+        Decorator to set config for this specific bot
+        
+        Example:
+            @bt.chatbot("pillsbot")
+            def pills_bot(message: str):
+                yield bt.Text("Pills bot response")
+            
+            @pills_bot.config
+            def pills_config():
+                return BotConfig(
+                    name="Pills Bot",
+                    description="Medication information bot"
+                )
+        """
+        self._config_func = func
+        # Register in the bot-specific config registry
+        _bot_config_registry[self.url_path] = func
+        return func
 
     async def __call__(
         self,
@@ -130,32 +159,83 @@ class ChatbotFunction:
                 return ComponentChatResponse(responses=components)
 
 
-def chatbot(name: str = None, stream: bool = None):
+def chatbot(name_or_url: Union[str, Callable] = None, stream: bool = None, name: str = None):
     """
     Decorator to create a BubbleTea chatbot from a function
 
     Args:
-        name: Optional name for the chatbot (defaults to function name)
+        name_or_url: Either a URL path (e.g., "pillsbot") or name for the chatbot
+                     If it starts without /, it's treated as a URL path
         stream: Whether to stream responses (auto-detected from generator functions)
+        name: Optional explicit name for the chatbot (defaults to function name)
 
     Example:
-        @chatbot()
+        @chatbot("pillsbot")  # Will be accessible at /pillsbot
         def my_bot(message: str):
             yield Text("Hello!")
-            yield Image("https://example.com/image.jpg")
+            
+        @chatbot()  # Will be accessible at /chat (default)
+        def another_bot(message: str):
+            return Text("Hi!")
     """
 
     def decorator(func: Callable) -> ChatbotFunction:
-        return ChatbotFunction(func, name=name, stream=stream)
+        # Determine URL path
+        url_path = None
+        bot_name = name
+        
+        if isinstance(name_or_url, str):
+            # If it doesn't start with /, treat it as URL path and prepend /
+            if not name_or_url.startswith("/"):
+                url_path = f"/{name_or_url}"
+            else:
+                url_path = name_or_url
+            # If no explicit name provided, derive from URL
+            if not bot_name:
+                bot_name = name_or_url.strip("/").replace("-", "_").replace("/", "_")
+        
+        chatbot_func = ChatbotFunction(func, name=bot_name, stream=stream, url_path=url_path)
+        
+        # Check if this URL path is already registered
+        if chatbot_func.url_path in _chatbot_registry:
+            raise ValueError(
+                f"A chatbot is already registered at URL path '{chatbot_func.url_path}'. "
+                f"Each chatbot must have a unique URL path."
+            )
+        
+        # Register the chatbot function in the global registry
+        _chatbot_registry[chatbot_func.url_path] = chatbot_func
+        
+        return chatbot_func
 
     # Allow using @chatbot without parentheses
-    if callable(name):
-        func = name
-        return ChatbotFunction(func)
+    if callable(name_or_url):
+        func = name_or_url
+        chatbot_func = ChatbotFunction(func)
+        
+        # Check if this URL path is already registered
+        if chatbot_func.url_path in _chatbot_registry:
+            raise ValueError(
+                f"A chatbot is already registered at URL path '{chatbot_func.url_path}'. "
+                f"Each chatbot must have a unique URL path."
+            )
+        
+        _chatbot_registry[chatbot_func.url_path] = chatbot_func
+        return chatbot_func
 
     return decorator
 
 
+def get_registered_chatbots() -> Dict[str, ChatbotFunction]:
+    """Get all registered chatbot functions"""
+    return _chatbot_registry.copy()
+
+
+def get_bot_configs() -> Dict[str, Callable]:
+    """Get all registered bot-specific config functions"""
+    return _bot_config_registry.copy()
+
+
 def config(path: str = "/config"):
     """
     Decorator to define bot configuration endpoint
